Certificate class
Constructors
Properties
- algorithm ↔ String?
-
getter/setter pair
- alias ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- issuer ↔ String?
-
getter/setter pair
- oid ↔ String?
-
getter/setter pair
- owner ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber ↔ String?
-
getter/setter pair
- validFrom ↔ String?
-
getter/setter pair
- validTo ↔ String?
-
getter/setter pair
- version ↔ int?
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → Certificate