CryptoProFlutterApi class

Constructors

CryptoProFlutterApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for CryptoProFlutterApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCertificatesToTrustedStorage({required List<String> paths}) Future<void>
deleteCertificateWithPKeyFromPersonalStorage(String certificateAlias) Future<void>
getCertificateWithPrivateKeyFromPersonalContainer({required String certificateAlias, required String password}) Future<Certificate>
getInstalledCertificatesWithPrivateKeys() Future<List<Certificate>>
getLicense() Future<CryptoProLicenseInfo?>
importContainerFromExternalStorage({required String storageName, required String password, String? newPassword}) Future<List<Certificate>>
importPFXContainer({required String filePath, required String password, String? newPassword}) Future<List<Certificate>>
initCSP() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readContainerFromExternalStorage({required String storageName, required String password}) Future<List<Certificate>>
setLicense(String number) Future<bool>
signFile({required String filePath, required String certificateAlias, required String password, required CAdESFormat format, bool signHash = false, bool isDetached = true, bool disableOnlineValidation = false, String? tsaUrl, String? storageName}) Future<SuccessSign>
signMessage({required String message, required String certificateAlias, required String password, required CAdESFormat format, bool isDetached = true, bool signHash = false, bool disableOnlineValidation = false, String? tsaUrl, String? storageName}) Future<SuccessSign>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>